gg_args library

Classes

DirCommand<T>
Base class for all ggGit commands
DirCommandExample
Example git command implementation
GgCommandRunner
A command runner that automatically forwards to a single sub command.
MockDirCommand<T>
Mock for DirCommand
UnknownSubCommandRunner
A CommandRunner that reports unknown sub commands also with --help.
VoidDirCommandExample
Example git command implementation

Functions

missingSubCommands({required Directory directory, required Command command, List<String> additionalSubCommands = const []}) Future<(List<String>, String?)>
Returns a list of missing sub commands in directory